# Pygsuite

[![Join the chat at https://gitter.im/pygsuite/community](https://badges.gitter.im/pygsuite/community.svg)](https://gitter.im/pygsuite/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

This package provides utilities for working Gsuite products such as sheets, docs, and slides 
in a pythonic, object-oriented way.

It currently offers abstractions for

- Sheets
- Slides
- Docs
- Drive

## Documentation

[Read the Docs](https://pygsuite.readthedocs.io/en/latest/)